@@ -32,8 +32,16 @@ class Procedure(BaseModel):
         description="First and last name of the experimenter.",
         title="Experimenter full name",
     )
-    protocol_id: str = Field(..., title="Protocol ID")
-    animal_weight: Optional[float] = Field(None, title="Animal weight (g)")
+    protocol_id: str = Field(
+        ..., title="Protocol ID", description="DOI for protocols.io"
+    )
+    iacuc_protocol: Optional[str] = Field(None, title="IACUC protocol")
+    animal_weight: Optional[float] = Field(
+        None,
+        title="Animal weight (g)",
+        description="Animal weight before procedure",
+        units='g'
+    )
     notes: Optional[str] = Field(None, title="Notes")
 
 
@@ -193,6 +201,7 @@ class TissuePrep(Procedure):
     """Description of a tissue preparation procedure"""
 
     name: TissuePrepName = Field(..., title="Name")
+    specimen_id: List[str] = Field(..., title="Specimen ID")
 
 
 class TrainingProtocol(BaseModel):
@@ -275,7 +284,7 @@ class Procedures(AindSchema):
     """Description of all procedures performed on a subject"""
 
     schema_version: str = Field(
-        "0.4.1", description="schema version", title="Version", const=True
+        "0.4.2", description="schema version", title="Version", const=True
     )
     subject_id: str = Field(
         ...,
@@ -306,4 +315,7 @@ class Procedures(AindSchema):
     tissue_preparations: Optional[List[TissuePrep]] = Field(
         None, title="Tissue preparations", unique_items=True
     )
+    other_procedures: Optional[List[Procedure]] = Field(
+        None, title="Other procedures", unique_items=True
+    )
     notes: Optional[str] = Field(None, title="Notes")
